@@ -1,4 +1,6 @@
 /*
+ * $Id: pilot-addresses.c,v 1.88 2007/01/15 06:11:33 desrod Exp $ 
+ *
  * pilot-addresses.c:  Palm address transfer utility
  *
  * This program is free software; you can redistribute it and/or modify it
@@ -752,7 +754,7 @@ int main(int argc, const char *argv[])
                        "different structure. Your Palm has \"Contacts\", and this tool reads the\n"
                        "\"AddressBook\" database.\n\n"
 
-                       "Due to this chnage, pilot-addresses and other tools must be rewritten to\n"
+                       "Due to this change, pilot-addresses and other tools must be rewritten to\n"
                        "compensate. Sorry about the inconvenience.\n\n");
                 return -1;
         }
@@ -868,3 +870,10 @@ error_close:
 error:
         return -1;
 }
+
+/* vi: set ts=8 sw=4 sts=4 noexpandtab: cin */
+/* ex: set tabstop=4 expandtab: */
+/* Local Variables: */
+/* indent-tabs-mode: t */
+/* c-basic-offset: 8 */
+/* End: */
