@@ -1,4 +1,6 @@
 /*
+ * $Id: pilot-dlpsh.c,v 1.1.1.2 2007-02-14 21:21:15 rousseau Exp $ 
+ *
  * pilot-dlpsh.c: DLP Command Shell
  *
  * (c) 1996, 2000, The pilot-link Team
@@ -27,6 +29,8 @@
 #include <stdlib.h>
 #include <string.h>
 #include <strings.h>
+#include <sys/time.h>
+
 #ifdef HAVE_SYS_TYPES_H
 #include <sys/types.h>
 #endif
@@ -377,6 +381,7 @@ int time_fn(int sd, int argc, const char *argv[])
 	int 	s;
 	time_t 	ltime;
 	struct 	tm *tm_ptr;
+	struct	timeval tv;
 	char 	timebuf[80];
 
 	time(&ltime);
@@ -385,6 +390,9 @@ int time_fn(int sd, int argc, const char *argv[])
 	strftime(timebuf, 80, "Now setting Palm time from desktop to: "
 			      "%a %b %d %H:%M:%S %Z %Y\n", tm_ptr);
 	printf(timebuf);
+	gettimeofday(&tv, 0);
+	ltime = tv.tv_sec + 1;
+	usleep(1000000 - tv.tv_usec);
 	s = dlp_SetSysDateTime(sd, ltime);
 
 	return 0;
@@ -829,3 +837,10 @@ error_close:
 error:
 	return -1;
 }
+
+/* vi: set ts=8 sw=4 sts=4 noexpandtab: cin */
+/* ex: set tabstop=4 expandtab: */
+/* Local Variables: */
+/* indent-tabs-mode: t */
+/* c-basic-offset: 8 */
+/* End: */
